#!/usr/bin/env bash
# set -x
# set -e

check_docker_access() {
    if id -nG "$USER" | grep -qw docker; then
        return
    elif [[ "$USER" = "root" ]]; then
        return
    else
        printf "Текущий пользователь не добавлен в группу docker и не может управлять контейнерами. \nДобавьте текущего пользователя в группу docker или используйте другого пользователя находящегося в этой группе."
        exit 1
    fi
}

image_load() {
    local name="$1"
    local compose_file="$2"
    local image_file="$(find ./ -name "$name-*.tar" -type f)"
    echo "Импорт из файла $image_file"
    local tag="$(docker load --input "$image_file" --quiet | cut -d ':' -f 2-3 | tr -d ' ')"
    sed -i "s/$name-build:latest/$tag/g" "$compose_file"
}

install() {
    printf "Начало установки... \n"

    if ! image_load eea docker-compose.yml
    then
        printf "Ошибка импорта образа."
        exit 1
    fi

    printf "Установка завершена. Не забудьте заполнить файл .env!\n"
}

upgrade() {
    printf "Начало обновления... \n"
    local container_id="$(docker ps | grep ews-connector | cut -d ' ' -f 1 | head -1)"
    local compose_dir="$(docker inspect "$container_id" | grep 'com.docker.compose.project.working_dir' | tr -d ' ' | cut -d ':' -f 2 | tr -d '",')"
    cd "$compose_dir" || exit
    docker compose down || docker-compose down
    cd - || exit

    if ! image_load eea docker-compose.yml
    then
        printf "Ошибка импорта образа."
        exit 1
    fi

    printf "Обновление завершено. Не забудьте заполнить файл .env!\n"
}

main() {
    printf "
 __    __    __                           ___                        
|_ | |(_    /   _ __ __  _  _ _|_ _  __    | __  _ _|_ _  |  |  _  __
|__|^|__)   \__(_)| || |(/_(_  |_(_) |    _|_| |_>  |_(_| |  | (/_ | 
    "
    printf "\nДобро пожаловать!\n"

    check_docker_access

    case "$1" in
        -u)
        upgrade
        ;;
        *)
        install
        ;;
    esac
}

main "$@"